import { doc, collection } from 'firebase/firestore';
import { collectionData, docData } from 'rxfire/firestore';

function createSimpleFirestoreDataConverter(config) {
    return {
        fromFirestore: (snapshot, options) => config.toModel(snapshot.data(options)),
        toFirestore: (model) => config.toRecord(model),
    };
}

/**
 * A class that provides type-safe access to the Firestore collection and
 * documents of a specific model.
 */
class FirestoreResource {
    constructor(firestore, config) {
        this.firestore = firestore;
        this.config = config;
        this.path = this.config.path;
        this.idField = this.config.idField;
        this.converter = this.config.converter;
    }
    refDoc(id) {
        const { path, converter } = this;
        return doc(this.firestore, path, id).withConverter(converter);
    }
    refNewDoc() {
        const { converter } = this;
        const collectionRef = this.refCollection();
        return doc(collectionRef).withConverter(converter);
    }
    refCollection() {
        const { path, converter } = this;
        return collection(this.firestore, path).withConverter(converter);
    }
    resolveQuery(query) {
        const { idField } = this;
        // Type-assert required because of the incorrect typing of the `idField` option
        return collectionData(query, { idField });
    }
    resolveDoc(ref) {
        const { idField } = this;
        // Type-assert required because of the incorrect typing of the `idField` option
        return docData(ref, { idField });
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { FirestoreResource, createSimpleFirestoreDataConverter };
//# sourceMappingURL=angularity-fire-firestore.mjs.map
