import { CollectionReference, DocumentData, DocumentReference, Firestore, FirestoreDataConverter, Query } from 'firebase/firestore';
import { Observable } from 'rxjs';
export interface FirestoreResourceConfig<ModelWithId extends DocumentData, Record extends DocumentData, IdField extends keyof ModelWithId> {
    readonly path: string;
    readonly idField: IdField;
    readonly converter: FirestoreDataConverter<Omit<ModelWithId, IdField>, Record>;
}
/**
 * A class that provides type-safe access to the Firestore collection and
 * documents of a specific model.
 */
export declare class FirestoreResource<ModelWithId extends DocumentData, Record extends DocumentData, IdField extends keyof ModelWithId> {
    protected firestore: Firestore;
    protected config: FirestoreResourceConfig<ModelWithId, Record, IdField>;
    constructor(firestore: Firestore, config: FirestoreResourceConfig<ModelWithId, Record, IdField>);
    readonly path: string;
    readonly idField: IdField;
    readonly converter: FirestoreDataConverter<Omit<ModelWithId, IdField>, Record>;
    refDoc(id: string): DocumentReference<Omit<ModelWithId, IdField>, Record>;
    refNewDoc(): DocumentReference<Omit<ModelWithId, IdField>, Record>;
    refCollection(): CollectionReference<Omit<ModelWithId, IdField>, Record>;
    resolveQuery(query: Query<Omit<ModelWithId, IdField>>): Observable<ModelWithId[]>;
    resolveDoc(ref: DocumentReference<Omit<ModelWithId, IdField>>): Observable<ModelWithId | undefined>;
}
